mindroot.registry package - MindRoot 9.10.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# mindroot.registry package

## Submodules

## mindroot.registry.component_manager module

class mindroot.registry.component_manager.ComponentManager

  Bases: `object`

  get_component_metadata(component_type, name)
  is_component_activated(component_type, name)
  is_component_installed(component_type, name)
  list_components(component_type)
  register_component(component_type, name, metadata)

## mindroot.registry.data_access module

class mindroot.registry.data_access.DataAccess

  Bases: `object`

  add_plugin(plugin_data)
  add_provider(provider_data)
  get_model(model_name)
  get_provider(provider_name)
  read_equivalent_flags()
  read_json(file_path)
  read_models()
  read_plugins()
  read_preferred_models()
  read_providers()
  remove_plugin(plugin_name)
  remove_provider(provider_name)
  update_model(model_name, updates)
  update_plugin(plugin_name, updates)
  update_provider(provider_name, updates)
  write_equivalent_flags(flags)
  write_json(file_path, data)
  write_models(models)
  write_plugins(plugins)
  write_preferred_models(models)
  write_providers(providers)

## Module contents